#!/usr/bin/python
# -*- coding: utf-8 -*-
"""
   This module privides pretty printing for list/dict/tuple python object.

   Simple example of usage is followings

       >>> from prettyprint import pp
       >>> target = ['want pretty printing', '望麗出力']
       >>> print target
       ['want pretty printing', '\\xe6\\x9c\\x9b\\xe9\\xba\\x97\\xe5\\x87\\xba\\xe5\\x8a\\x9b']  # what a ugly print especially in japanese
       >>> pp(target)   # now we can see pretty print with pp
       [
           "want pretty printing", 
           "望麗出力"
       ]
       >>> target_dict = {'order': {'en':'print prettily', 'ja':'綺麗に出力せよ'}}
       >>> print target_dict  # what a hell again
       {'order': {'en': 'print prettily', 'ja': '\\xe7\\xb6\\xba\\xe9\\xba\\x97\\xe3\\x81\\xab\\xe5\\x87\\xba\\xe5\\x8a\\x9b\\xe3\\x81\\x9b\\xe3\\x82\\x88'}}
       >>> pp(target_dict)  # pp again
       {
           "order": {
               "en": "print prettily", 
               "ja": "綺麗に出力せよ"
           }
       }
"""

__author__  = "Matsumoto Taichi"
__version__ = "0.1.3"
__license__ = "MIT License"

from prettyprint import *



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
import sys
import unittest

import prettyprint
from prettyprint import __version__, __license__, __author__, __doc__

if __name__ == '__main__':
  # build distribution package
  setup(
    packages         = ('prettyprint',),
    name             = 'prettyprint',
    version          = __version__,
    py_modules       = find_packages(exclude=["test"]),
#    install_requires = ['simplejson>=2.0.9'],     # error occurs in my environment...
    description      = 'prettyprint print list/dict/tuple object prettily',
    long_description = __doc__,
    test_suite       = 'test',
    author           = __author__,
    author_email     = 'taichino@gmail.com',
    url              = 'http://github.com/taichino/prettyprint',
    keywords         = 'pretty print',
    license          = __license__,
    classifiers      = ["Development Status :: 3 - Alpha",
                        "Intended Audience :: Developers",
                        "License :: OSI Approved :: MIT License",
                        "Operating System :: POSIX",
                        "Programming Language :: Python",
                        "Topic :: Software Development :: Libraries :: Python Modules"]
  )
